unit BLAbout;

// ****************************************************************
// USB Bootloader Pro version 2.1
// Copyright (c) 2010 Trace Systems, Inc.
// All Rights Reserved
//
// General purpose USB bootloader program that can be easily used
// and branded by our customers, with no programming needed at all.
//
// This source code proprietary to Trace Systems Inc.
// ****************************************************************

interface

uses Windows, SysUtils, Classes, Graphics, Forms, Controls, StdCtrls,
  Dialogs, Buttons, ExtCtrls, {RzLabel,} Vcl.ExtCtrls, jpeg,
  Vcl.Imaging.pngimage;

  //{System.PChar,} Vcl.Imaging.pngimage

type
  TAboutBox = class(TForm)
    OKButton: TButton;
    Panel2: TPanel;
    ProductNameLbl: TLabel;
    Version: TLabel;
    Copyright: TLabel;
    Comments: TLabel;
    Label5: TLabel;
    RegToLbl: TLabel;
    Label6: TLabel;
    SerNumLbl: TLabel;
    Label7: TLabel;
    ActivationKeyLbl: TLabel;
    Label8: TLabel;
    Label9: TLabel;
    Error_1_WebLabel: TWebLabel;
    Error_2_WebLabel: TWebLabel;
    WebImageControl1: TWebImageControl;
    Image1: TWebImageControl;
    procedure FormCreate(Sender: TObject);
    procedure Image1MouseDown(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure FormShow(Sender: TObject);
  private
    FRegistered: Boolean;
    FRegistrationURL: String;
    FFileVersionStr: String;
    FMajorVerNum: Integer;
    FReleaseVerNum: Integer;
    FMinorVerNum: Integer;
    FBuildVerNum: Integer;
    function GetActivationKey: String;
    function GetActivatorName: String;
    function GetProductName: String;
    function GetTraceSerialNum: String;
    procedure SetActivationKey(const Value: String);
    procedure SetActivatorName(const Value: String);
    procedure SetProductName(const Value: String);
    procedure SetRegistered(const Value: Boolean);
    procedure SetTraceSerialNum(const Value: String);
    procedure SetRegistrationURL(const Value: String);
    { Private declarations }
  public
    { Public declarations }
    property TraceSerialNum : String read GetTraceSerialNum write SetTraceSerialNum;
    property ActivatorName : String read GetActivatorName write SetActivatorName;
    property ActivationKey : String read GetActivationKey write SetActivationKey;
    property ProductName : String read GetProductName write SetProductName;
    property Registered : Boolean read FRegistered write SetRegistered;
    property RegistrationURL : String read FRegistrationURL write SetRegistrationURL;
    property FileVersionStr : String read FFileVersionStr;
    property MajorVerNum : Integer read FMajorVerNum;
    property MinorVerNum : Integer read FMinorVerNum;
    property ReleaseVerNum : Integer read FReleaseVerNum;
    property BuildVerNum : Integer read FBuildVerNum;
  end;

var
  AboutBox: TAboutBox;

implementation

{$R *.dfm}

uses
  //BLPro_M;
  //dsProgEv4_M;
  WC_UI_0;

procedure TAboutBox.FormCreate(Sender: TObject);
const
  InfoNum = 10;
  InfoStr: array[1..InfoNum] of string = ('CompanyName',        // 1
                                          'FileDescription',    // 2
                                          'FileVersion',        // 3
                                          'InternalName',       // 4
                                          'LegalCopyright',     // 5
                                          'LegalTradeMarks',    // 6
                                          'OriginalFileName',   // 7
                                          'ProductName',        // 8
                                          'ProductVersion',     // 9
                                          'Comments');          //10
var
  S, NumStr, ErrStr : string;
  n, Len, i, Index, Count, Code : DWORD;
  Buf: PChar;
  //Buf: System.PChar;
  Value: PChar;
  VerStrings : array[1..InfoNum] of String;
  VersionArray : array[0..3] of Integer;
begin
  S := Application.ExeName;
  n := GetFileVersionInfoSize(PChar(S), n);
  if n > 0 then
    begin
      Buf := AllocMem(n);
      // Read whole batch of version info into Buf
      GetFileVersionInfo(PChar(S), 0, n, Buf);
      // Decode each item
      for i := 1 to InfoNum do
        begin
          if VerQueryValue(Buf, PChar('StringFileInfo\040904E4\' + InfoStr[i]), Pointer(Value), Len)
            then VerStrings[i] := Value;
        end;
      FreeMem(Buf, n);

      // Now we can use them
      FFileVersionStr := VerStrings[3];

      n := 1;  // index into AStrings[3]
      Len := Length(VerStrings[3]);
      for i := 0 to 2 do
        begin
          //
          S := Copy(VerStrings[3], n, 50);  // Should be substring just after latest period
          Index := Pos('.', S);    // position of next period in substring
          Count := Index - 1;      // num digits before next period
          NumStr := Copy(S, 1, Count);   // substring containing digits only
          Val(NumStr, VersionArray[i], Code);
          if Code > 0 then
            begin
              //
              ErrStr := Format('Error: Invalid version string "%s"',[VerStrings[3]]);
              MessageDlg(ErrStr, mtError, [mbOK], 0);
              Close;
            end;
          n := n + Index; // point to char after latest period
        end;
      // There is one more version number to get
      //Count := len - index;
      //NumStr := RightStr(AStrings[3], Count);
      NumStr := Copy(VerStrings[3], n, 50);
      Val(NumStr, VersionArray[3], Code);
          if Code > 0 then
            begin
              //
              ErrStr := Format('Error: Invalid version string "%s"',[VerStrings[3]]);
              MessageDlg(ErrStr, mtError, [mbOK], 0);
              Close;
            end;
      FMajorVerNum := VersionArray[0];
      FMinorVerNum := VersionArray[1];
      FReleaseVerNum := VersionArray[2];
      FBuildVerNum := VersionArray[3];


{$IFNDEF Demo}
  {$IFDEF TrainingVersion}
      // Training version...
      Version.Caption := 'Version ' + VerStrings[3] + ' TRAINING EDITION';
  {$ELSE}
      // The real thing...
      Version.Caption := 'Version ' + VerStrings[3];
  {$ENDIF}
{$ELSE}
      // No code generation in Demo
      Version.Caption := 'Version ' + VerStrings[3] + '  DEMO';
{$ENDIF}
      Copyright.Caption := VerStrings[5];
      Comments.Caption := VerStrings[10];
      ProductName := VerStrings[8];
    end;
end;

procedure TAboutBox.Image1MouseDown(Sender: TObject; Button: TMouseButton;
  Shift: TShiftState; X, Y: Integer);
begin
  //
  if ssRight in Shift	 then
    begin
      //
      //MainForm.ClearActivationBtnClick(Self);
    end;

end;

// ****************************************************************************
// Property Get /Set access methods
// ****************************************************************************

// ActivationKey

function TAboutBox.GetActivationKey: String;
begin
  //
  Result := ActivationKeyLbl.Caption;
end;

procedure TAboutBox.SetActivationKey(const Value: String);
begin
  //
  ActivationKeyLbl.Caption := Value;
end;

// ActivatorName

function TAboutBox.GetActivatorName: String;
begin
  //
  Result := RegToLbl.Caption;
end;

procedure TAboutBox.SetActivatorName(const Value: String);
begin
  //
  RegToLbl.Caption := Value;
end;

// TraceSerialNum

function TAboutBox.GetTraceSerialNum: String;
begin
  //
  Result := SerNumLbl.Caption;
end;

procedure TAboutBox.SetTraceSerialNum(const Value: String);
begin
  //
  SerNumLbl.Caption := Value;
end;

// ProductName

function TAboutBox.GetProductName: String;
begin
  //
  Result := ProductNameLbl.Caption;
end;

procedure TAboutBox.SetProductName(const Value: String);
var
  LblWidth, ImgRight : Integer;
begin
  //
  ProductNameLbl.Caption := Value;
  SupportLinkLabel.URL := 'mailto:support@tracesystemsinc.com?subject=Need help on product: '
                         + Value;

  {
  // Adjust centering here:
  ImgRight := Image1.BoundsRect.Right;
  LblWidth := ProductNameLbl.Width;
  //ProductNameLbl.Left := (ClientWidth - LblWidth) div 2;
  ProductNameLbl.Left := ImgRight + ((ClientWidth - ImgRight - LblWidth) div 2);
  }
end;

procedure TAboutBox.SetRegistered(const Value: Boolean);
begin
  FRegistered := Value;
  if FRegistered then
    begin
      // Registered: change the link to a support request by email
      LinkLbl.URL := 'mailto:support@tracesystemsinc.com?subject=Need help on Product Activation Test program';
      LinkLbl.Caption := 'Click here to request tech support';
    end
  else
    begin
      // Unregisted: link to registration page on our site
      LinkLbl.URL := 'http://www.tracesystemsinc.com/register-tcpm.html';
      LinkLbl.Caption := 'Click here to register your product';
    end;
end;

procedure TAboutBox.FormShow(Sender: TObject);
var
  LblWidth, ImgRight : Integer;
begin
  // Let's try to adjust centering of a few labels
  //ImgRight := Image1.BoundsRect.Right;

  // Adjust centering here: ProductNameLbl
  //LblWidth := ProductNameLbl.Width;
  //ProductNameLbl.Left := (ClientWidth - LblWidth) div 2;
  //ProductNameLbl.Left := ImgRight + ((ClientWidth - ImgRight - LblWidth) div 2);
  LblWidth := ProductNameLbl.Width;
  ProductNameLbl.Left := (ClientWidth - LblWidth) div 2;

  // Adjust centering here: Version
  //LblWidth := Version.Width;
  //Version.Left := (ClientWidth - LblWidth) div 2;
  //Version.Left := ImgRight + ((ClientWidth - ImgRight - LblWidth) div 2);
  LblWidth := Version.Width;
  Version.Left := (ClientWidth - LblWidth) div 2;

  // Adjust centering here: Copyright
  LblWidth := Copyright.Width;
  Copyright.Left := (ClientWidth - LblWidth) div 2;

  // Adjust centering here: Comments
  LblWidth := Comments.Width;
  Comments.Left := (ClientWidth - LblWidth) div 2;

  // Adjust centering here: LinkLbl
  LblWidth := LinkLbl.Width;
  LinkLbl.Left := (ClientWidth - LblWidth) div 2;
end;

procedure TAboutBox.SetRegistrationURL(const Value: String);
var
  LblWidth : Integer;
begin
  FRegistrationURL := Value;
  LinkLbl.Caption := Value;
  LinkLbl.URL := Value;

  // Adjust centering here: LinkLbl
  LblWidth := LinkLbl.Width;
  LinkLbl.Left := (ClientWidth - LblWidth) div 2;
end;

end.

